//
// C++ Interface: CGuiosbuttonEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CGUIOSBUTTONEDITDLG_H
#define CGUIOSBUTTONEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_guiosbuttondlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CGUIOSButtonEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CGUIOSButtonEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CGUIOSButtonEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditColor();
    
private slots:
 
protected:
    Ui::GUIOSButtonEditDlg ui;    
    FolderListItem *point;
    QColor mycolor;
    
private:
    QWidget *myParent;
};
#endif
